@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.3Dev
+ *             Automatically Tuned Linear Algebra Software v3.3.6
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -42,6 +42,7 @@
 /*
  * predefined type macro names
  */
+#define ATL_trtri    Mjoin(PATL,trtri)
 #define ATL_potrfU   Mjoin(PATL,potrfU)
 #define ATL_potrfL   Mjoin(PATL,potrfL)
 #define ATL_potrs    Mjoin(PATL,potrs)
@@ -72,6 +73,8 @@ int ATL_sgetrfR(const int M, const int N, float *A, const int lda,
                 int *ipiv);
 int ATL_spotrfU(const int N, float *A, const int lda);
 int ATL_spotrfL(const int N, float *A, const int lda);
+int ATL_strtri(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
+               const enum CBLAS_DIAG Diag, const int N, float *A, const int lda);
 
 int ATL_dpotrf(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
                const int N, double *A, const int lda);
@@ -91,6 +94,8 @@ int ATL_dgetrfR(const int M, const int N, double *A, const int lda,
                 int *ipiv);
 int ATL_dpotrfU(const int N, double *A, const int lda);
 int ATL_dpotrfL(const int N, double *A, const int lda);
+int ATL_dtrtri(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
+               const enum CBLAS_DIAG Diag, const int N, double *A, const int lda);
 
 int ATL_cpotrf(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
                const int N, float *A, const int lda);
@@ -110,6 +115,8 @@ int ATL_cgetrfR(const int M, const int N, float *A, const int lda,
                 int *ipiv);
 int ATL_cpotrfU(const int N, float *A, const int lda);
 int ATL_cpotrfL(const int N, float *A, const int lda);
+int ATL_ctrtri(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
+               const enum CBLAS_DIAG Diag, const int N, float *A, const int lda);
 
 int ATL_zpotrf(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
                const int N, double *A, const int lda);
@@ -129,5 +136,17 @@ int ATL_zgetrfR(const int M, const int N, double *A, const int lda,
                 int *ipiv);
 int ATL_zpotrfU(const int N, double *A, const int lda);
 int ATL_zpotrfL(const int N, double *A, const int lda);
+int ATL_ztrtri(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
+               const enum CBLAS_DIAG Diag, const int N, double *A, const int lda);
 
 #endif
+
+
+
+
+
+
+
+
+
+
