@@ -1,7 +1,9 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.3Dev
+ *             Automatically Tuned Linear Algebra Software v3.3.6
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
- *                    (C) Copyright 1999 R. Clint Whaley
+ *                   (C) Copyright 2001 Peter Soendergaard
+ *
+ * Code contributers : Peter Soendergaard, R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -29,9 +31,34 @@
  * POSSIBILITY OF SUCH DAMAGE.
  *
  */
-
 #define DREAL
 #include "atlas_misc.h"
 #include "atlas_lapack.h"
 #include "clapack.h"
 
+int clapack_dtrtri(const enum ATLAS_ORDER Order,
+                        const enum ATLAS_UPLO Uplo,
+                        const enum ATLAS_DIAG Diag,
+                  const int N, double *A, const int lda)
+{
+   if (Order != CblasRowMajor && Order != CblasColMajor)
+      cblas_xerbla(1, "clapack_dtrtri",
+                   "Order must be %d or %d, but is set to %d\n",
+                   CblasRowMajor, CblasColMajor, Order);
+   if (Uplo != CblasUpper && Uplo != CblasLower)
+      cblas_xerbla(2, "clapack_dtrtri",
+                   "Uplo must be %d or %d, but is set to %d\n",
+                   CblasUpper, CblasLower, Uplo);
+   if (Diag != CblasUnit && Diag != CblasNonUnit)
+      cblas_xerbla(3, "clapack_dtrtri",
+                   "Diag must be %d or %d, but is set to %d\n",
+                   CblasNonUnit, CblasUnit, Diag);
+   if (N < 0)
+      cblas_xerbla(4, "clapack_dtrtri",
+                   "N cannot be less than zero 0,; is set to %d.\n", N);
+   if (lda < N || lda < 1)
+      cblas_xerbla(6, "clapack_dtrtri",
+                   "lda must be >= MAX(N,1): lda=%d N=%d\n", lda, N);
+
+   return(ATL_dtrtri(Order, Uplo, Diag, N, A, lda));
+}
