@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.3Dev
+ *             Automatically Tuned Linear Algebra Software v3.3.6
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                   (C) Copyright 1999 Peter Soendergaard
  *
@@ -39,7 +39,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'b'  */
    /*  nu = 4  */
    /*  k_loop = 'for'  */
@@ -49,7 +49,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 1  */
    /*  ku = 8  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'double'  */
@@ -94,7 +94,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
