@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.3Dev
+ *             Automatically Tuned Linear Algebra Software v3.3.6
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                   (C) Copyright 1999 Peter Soendergaard
  *
@@ -64,7 +64,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    while(pB0 != stN)
    {
       do /* M-loop */
