@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.3Dev
+ *             Automatically Tuned Linear Algebra Software v3.3.6
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                   (C) Copyright 1999 Peter Soendergaard
  *
@@ -39,7 +39,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  k_loop = None  */
@@ -49,12 +49,12 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  ku = 4  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
    /*  m_cleanup = {}  */
-   /*  used_outside_len = 60  */
+   /*  used_outside_len = 64  */
    /*  k_cleanup = {'mustfit': 56, 'method': 'acc1', 'compile': 1}  */
    /*  outputdir = 'Linux_PIII/'  */
    /*  arch = 'sse'  */
@@ -62,7 +62,7 @@ void ATL_USERMM
    /*  atlasname = 'Linux_PIII'  */
    /*  method = 'acc'  */
    /*  used_lastuse = 'b'  */
-   /*  outside_len = 60  */
+   /*  outside_len = 64  */
    /*  lastuse = 1  */
    /*  veclen = 4  */
    /*  sched = ['fuse', 'spread']  */
@@ -80,8 +80,8 @@ void ATL_USERMM
    float *pC0 = C;
    const float *stM = A + MB*KB;
    const float *stN = B + NB*KB;
-   const int incAm = 2*KB-KB+60;
-   const int incBm = -KB+60;
+   const int incAm = 2*KB-KB+64;
+   const int incBm = -KB+64;
    const int incCm = (2 SHIFT);
    const int incAn = -MB*KB;
    const int incBn = 1*KB;
@@ -91,7 +91,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -194,11 +194,17 @@ void ATL_USERMM
          vec_add_rr(reg3,reg0);
          vec_mul_mr_a(pA0+52+KB,reg6);
          vec_add_rr(reg6,reg1);
-         vec_mov_mr_a(pB0+56,reg5);
-         vec_mov_mr_a(pA0+56,reg2);
+         vec_mov_mr_a(pB0+56,reg7);
+         vec_mov_mr_a(pA0+56,reg4);
+         vec_mul_rr(reg7,reg4);
+         vec_add_rr(reg4,reg0);
+         vec_mul_mr_a(pA0+56+KB,reg7);
+         vec_add_rr(reg7,reg1);
+         vec_mov_mr_a(pB0+60,reg5);
+         vec_mov_mr_a(pA0+60,reg2);
          vec_mul_rr(reg5,reg2);
          vec_add_rr(reg2,reg0);
-         vec_mul_mr_a(pA0+56+KB,reg5);
+         vec_mul_mr_a(pA0+60+KB,reg5);
          vec_add_rr(reg5,reg1);
          vec_sum(reg0);
          vec_sum(reg1);
