@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.3Dev
+ *             Automatically Tuned Linear Algebra Software v3.3.6
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                   (C) Copyright 1999 Peter Soendergaard
  *
@@ -48,7 +48,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -57,7 +57,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 4  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -100,7 +100,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -179,7 +179,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -188,7 +188,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 4  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -231,7 +231,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -322,7 +322,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -331,7 +331,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 4  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -374,7 +374,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -477,7 +477,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -486,7 +486,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 4  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -529,7 +529,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -644,7 +644,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -653,7 +653,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 4  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -696,7 +696,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -823,7 +823,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -832,7 +832,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 4  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -875,7 +875,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -1014,7 +1014,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -1023,7 +1023,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -1066,7 +1066,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -1158,7 +1158,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -1167,7 +1167,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -1210,7 +1210,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -1308,7 +1308,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -1317,7 +1317,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -1360,7 +1360,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -1464,7 +1464,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -1473,7 +1473,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -1516,7 +1516,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -1626,7 +1626,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -1635,7 +1635,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -1678,7 +1678,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -1794,7 +1794,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -1803,7 +1803,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -1846,7 +1846,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -1968,7 +1968,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -1977,7 +1977,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -2020,7 +2020,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -2148,7 +2148,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -2157,7 +2157,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -2200,7 +2200,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
@@ -2334,7 +2334,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.2 $  */
+   /*  $Revision: 1.3 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  problem = 'gemm'  */
@@ -2343,7 +2343,7 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  k_loop = None  */
-   /*  rev = '$Revision: 1.2 $'  */
+   /*  rev = '$Revision: 1.3 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
@@ -2386,7 +2386,7 @@ void ATL_USERMM
 
    /*--- main program statements ---*/
    vec_mov_mr_1(&beta,reg0);
-   vec_mov_rm(reg0,&betavec);
+   vec_mov_rm(reg0,betavec);
    do /* N-loop */
    {
       do /* M-loop */
