@@ -152,7 +152,7 @@ FILENODE *ReadFile(char pre)
    char *pcc, *pccflags;
    int i, n, ID, alpha, beta, incX, incY;
 
-   sprintf(ln, "../COPY/%ccases.dsc", pre);
+   sprintf(ln, "%ccopy.dsc", pre);
    fpin = fopen(ln, "r");
    assert(fpin);
    assert(fgets(ln, 512, fpin) != NULL);
